@@ -1,9 +1,11 @@
+from collections.abc import Sequence
 from pathlib import Path
 from typing import Optional
 
 import click
 
 from komposer.core.base import generate_manifest_from_docker_compose
+from komposer.core.env_vars import replace_komposer_env_variables
 from komposer.types.cli import Context, DeploymentContext, IngressContext
 from komposer.utils import dump_yaml
 
@@ -11,9 +13,14 @@ DEFAULT_DOCKER_COMPOSE_FILENAME = Path("docker-compose.yml")
 DEFAULT_DOCKER_IMAGE = "${IMAGE}"
 
 
-def output_raw_manifest(manifest: dict) -> None:
+def output_raw_manifest(context: Context, manifest: dict) -> None:
+    # Convert manifest to string
     output = dump_yaml(manifest)
 
+    # Render KOMPOSER_* vars
+    output = replace_komposer_env_variables(context, output)
+
+    # Output manifest
     print(output)
 
 
@@ -36,6 +43,7 @@ def output_raw_manifest(manifest: dict) -> None:
 @click.option(
     "--extra-manifest",
     type=click.Path(file_okay=True, dir_okay=False, resolve_path=True, path_type=Path),
+    multiple=True,
     help=(
         "Path to an extra manifest file with custom items to be merged. "
         "The manifest must be in a format where the root element is a Kubernetes List node. "
@@ -76,8 +84,8 @@ def main(
     repository_name: str,
     branch_name: str,
     default_image: str,
+    extra_manifest: Sequence[Path],
     ingress_for_service: Optional[str] = None,
-    extra_manifest: Optional[Path] = None,
     ingress_tls_file: Optional[Path] = None,
     deployment_annotations_file: Optional[Path] = None,
     deployment_service_account_name: Optional[Path] = None,
@@ -89,7 +97,7 @@ def main(
         repository_name=repository_name,
         default_image=default_image,
         ingress_for_service=ingress_for_service,
-        extra_manifest_path=extra_manifest,
+        extra_manifest_paths=extra_manifest,
         ingress=IngressContext(tls_path=ingress_tls_file),
         deployment=DeploymentContext(
             annotations_path=deployment_annotations_file,
@@ -99,7 +107,7 @@ def main(
 
     manifest_data = generate_manifest_from_docker_compose(context)
 
-    output_raw_manifest(manifest_data)
+    output_raw_manifest(context, manifest_data)
 
 
 if __name__ == "__main__":
